Learn R Programming

MPDiR (version 0.1-12)

CorticalCells: Contrast Response Functions from Visual Cortical Cells

Description

The responses in impulses/second of 6 cells recorded in the macaque cortex in visual areas V1 and V2 to a series of contrasts of drifting sinusoidal gratings of optimal location, orientation, size and spatial frequency.

Usage

data(CorticalCells)

Arguments

source

Data collected in Peter Lennie's lab, analysis by Jon Peirce (see reference below)

Details

Extracellular recordings of cells from macaque visual cortical areas V1 and V2. Simple and complex cells were differentiated by whether or not the response rate, $f_0$, was greater than the amplitude of modulation at the drift rate, $f_1$. If $f_1 > f_0$, the cell was classified as a simple cell and the value of $f_1$ is reported; otherwise the cell is classified as a complex cell and the value of $f_0$ is reported. In both cases, the units are in impulses/second.

References

Peirce, J. W. (2007). The potential importance of saturating and supersaturating contrast response functions in visual cortex. Journal of Vision, 7(6):13, 1--10, http://journalofvision.org/7/6/13/.

Examples

Run this code
data(CorticalCells)
lattice:::xyplot(Response ~ Contrast | Cell, CorticalCells, 
	type = "b")

Run the code above in your browser using DataLab