Learn R Programming

MPDiR (version 0.1-12)

Grue: Distribution of Grue Languages with UV-B Exposure

Description

Data reported by Lindsey and Brown (2002) based on a corpus of 203 languages (only 201 represented in this data set) of the numbers of languages with separate words for blue and green, a combined word for the two, so-called grue-languages, or the word dark for the two, as a function of the average annual exposure to UV-B light.

Usage

data(Grue)

Arguments

source

Data kindly provided by Angela M. Brown.

References

D. T. Lindsey and A. M. Brown (2002) Color naming and the phototoxic effects of sunlight on the eye. Psychological Science, 13, 506-512.

Examples

Run this code
data(Grue)
barplot(t(as.matrix(Grue[, -1])), names.arg = round(Grue$UV_B, 1), 
	beside = TRUE, legend.text = c("blue-green", "grue", "dark"),
	col = c("white", "grey", "black"),
	ylim = c(0, 40), cex.lab = 1.5,
	xlab = expression(paste("Average UV-B (kJ/", m^2, ")")),
	ylab = "Numbers of Languages"
	)

Run the code above in your browser using DataLab