Learn R Programming

MPDiR (version 0.1-12)

StairCase: 3-1 Randomly Interleaved Staircase Detection Experiment

Description

Data from one observer performing a 2-alternative forced-choice detection experiment. A 3-1 staircase procedure was used with two randomly interleaved staircases.

Usage

data(StairCase)

Arguments

Details

The data were obtained using a 3-down, 1-up staircase procedure. The observer was required to make 3 successive correct judgments before the stimulus contrast was lowered; one incorrect response resulted in an increase in contrast at the next trial. Initially, the contrast was reduced by a factor of 2 for each sequence of 3 correct responses. After a first incorrect response, successive increments and decrements were by a factor of 1.26. Each staircase was 48 trials long. In the actual experiment, the two staircases were run concurrently, with the contrast level chosen by switching from one staircase to the other at random.

Examples

Run this code
clr = c("red", "blue")
with(StairCase, plot(Contrast ~ Trial, log = "y",
	col = clr[unclass(StairCase)], pch = 16))

Run the code above in your browser using DataLab