Learn R Programming

MPDiR (version 0.1-15)

Vernier: Psychometric Functions for Vernier Judgement of Phase Difference between Drifting Gratings

Description

A pair of adjacent, horizontal luminance gratings (sine- or square-wave spatial profiles, 0.8 cycles/degree and equal contrast = 0.30) drifting at 2 or 8 Hz. The gratings were separated by a 30-arcmin lateral gap. On each trial, the grating pair was drifting either upward or downward and the phase shift between the gratings was chosen at one of 8 values between -50 and 50 degrees. The observer was instructed to report which grating appeared shifted upward. The method of constant stimuli was used.

Usage

data(Vernier)

Arguments

source

Data kindly provided by H. Sun.

References

H. Sun, B. B. Lee and R. C. Baraas Systematic misestimation in a vernier task arising from contrast mismatch, Visual Neuroscience, 2008, 25, 365--370.

Examples

Run this code
data(Vernier)

Run the code above in your browser using DataLab